@@ -14,10 +14,15 @@
 #include <GrantleeTheme/GrantleeKi18nLocalizer>
 #include <GrantleeTheme/GrantleeTheme>
 #include <GrantleeTheme/GrantleeThemeEngine>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/context.h>
 #include <grantlee/metatype.h>
 #include <grantlee/templateloader.h>
+#else
+#include <KTextTemplate/context.h>
+#include <KTextTemplate/metatype.h>
+#include <KTextTemplate/templateloader.h>
+#endif
 
 #include <Akonadi/Item>
 
@@ -33,13 +38,21 @@
 
 using namespace KAddressBookGrantlee;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 GRANTLEE_BEGIN_LOOKUP(QUrl)
+#else
+KTEXTTEMPLATE_BEGIN_LOOKUP(QUrl)
+#endif
 if (property == QLatin1String("scheme")) {
     return object.scheme();
 } else if (property == QLatin1String("path")) {
     return object.path();
 }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 GRANTLEE_END_LOOKUP
+#else
+KTEXTTEMPLATE_END_LOOKUP
+#endif
 
 class KAddressBookGrantlee::GrantleeContactFormatterPrivate
 {
@@ -49,10 +62,15 @@ public:
         KConfig config(QStringLiteral("akonadi_contactrc"));
         KConfigGroup group(&config, QStringLiteral("View"));
         showQRCode = group.readEntry("QRCodes", true);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         mEngine = std::make_unique<GrantleeTheme::Engine>();
 
         mTemplateLoader = QSharedPointer<Grantlee::FileSystemTemplateLoader>(new Grantlee::FileSystemTemplateLoader());
+#else
+        mEngine = std::make_unique<KTextTemplate::Engine>();
+
+        mTemplateLoader = QSharedPointer<KTextTemplate::FileSystemTemplateLoader>(new KTextTemplate::FileSystemTemplateLoader());
+#endif
     }
 
     ~GrantleeContactFormatterPrivate()
@@ -77,10 +95,17 @@ public:
     }
 
     QVector<QObject *> mObjects;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     std::unique_ptr<GrantleeTheme::Engine> mEngine;
     QSharedPointer<Grantlee::FileSystemTemplateLoader> mTemplateLoader;
     Grantlee::Template mSelfcontainedTemplate;
     Grantlee::Template mEmbeddableTemplate;
+#else
+    std::unique_ptr<KTextTemplate::Engine> mEngine;
+    QSharedPointer<KTextTemplate::FileSystemTemplateLoader> mTemplateLoader;
+    KTextTemplate::Template mSelfcontainedTemplate;
+    KTextTemplate::Template mEmbeddableTemplate;
+#endif
     QString mErrorMessage;
     bool forceDisableQRCode = false;
     bool showQRCode = true;
@@ -89,7 +114,11 @@ public:
 GrantleeContactFormatter::GrantleeContactFormatter()
     : d(new GrantleeContactFormatterPrivate)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::registerMetaType<QUrl>();
+#else
+    KTextTemplate::registerMetaType<QUrl>();
+#endif
 }
 
 GrantleeContactFormatter::~GrantleeContactFormatter() = default;
@@ -134,7 +163,7 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     }
 
     if (rawContact.isEmpty()) {
-        return QString();
+        return {};
     }
 
     // Custom fields
@@ -228,20 +257,28 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     mapping.insert(QStringLiteral("customFields"), customFields);
     mapping.insert(QStringLiteral("customFieldsUrl"), customFieldsUrl);
     mapping.insert(QStringLiteral("hasqrcode"), !d->forceDisableQRCode && d->showQRCode);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Grantlee::Context context(mapping);
     context.setLocalizer(d->mEngine->localizer());
+#else
+    KTextTemplate::Context context(mapping);
+    // TODO context.setLocalizer(d->mEngine->localizer());
+#endif
 
     if (form == SelfcontainedForm) {
         return d->mSelfcontainedTemplate->render(&context);
     } else if (form == EmbeddableForm) {
         return d->mEmbeddableTemplate->render(&context);
     } else {
-        return QString();
+        return {};
     }
 }
 
 void GrantleeContactFormatter::setApplicationDomain(const QByteArray &domain)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     d->mEngine->localizer()->setApplicationDomain(domain);
+#else
+    // TODO qt6
+#endif
 }
